pub type FixedSizeListIter<'a> = ArrayIter<&'a FixedSizeListArray>;Expand description
an iterator that returns Some(T) or None, that can be used on any FixedSizeListArray
Aliased Type
pub struct FixedSizeListIter<'a> { /* private fields */ }pub type FixedSizeListIter<'a> = ArrayIter<&'a FixedSizeListArray>;an iterator that returns Some(T) or None, that can be used on any FixedSizeListArray
pub struct FixedSizeListIter<'a> { /* private fields */ }